#!/usr/bin/env python

import os
import sys

from setuptools import Extension, find_packages, setup

from minode import shared


README = open(os.path.join(
    os.path.abspath(os.path.dirname(__file__)), 'README.md')).read()

name, version = shared.user_agent.strip(b'/').split(b':')

bitmsghash = Extension(
    'minode.bitmsghash',
    sources=['minode/bitmsghash/bitmsghash.cpp'],
    libraries=['pthread', 'crypto'],
)

if sys.platform[:3] == 'win':
    bitmsghash.libraries = ['libeay32', 'ws2_32']
    openssl_dir = os.getenv('OPENSSL_DIR')
    if openssl_dir:
        bitmsghash.library_dirs = [os.path.join(openssl_dir, 'lib')]
        bitmsghash.include_dirs = [os.path.join(openssl_dir, 'include')]

setup(
    name=name.decode('utf-8'),
    version=version.decode('utf-8'),
    description='Python 3 implementation of the Bitmessage protocol.'
    ' Designed only to route objects inside the network.',
    long_description=README,
    license='MIT',
    author='Krzysztof Oziomek',
    url='https://git.bitmessage.org/lee.miller/MiNode',
    packages=find_packages(exclude=('*tests',)),
    package_data={'': ['*.csv', 'tls/*.pem']},
    ext_modules=[bitmsghash],
    entry_points={'console_scripts': ['minode = minode.main:main']},
    classifiers=[
        "License :: OSI Approved :: MIT License"
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Topic :: Internet",
        "Topic :: Security :: Cryptography",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
)
